;;; DO NOT MODIFY THIS FILE
(if (featurep 'egg-its-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "egg-its/_pkg.el")

(package-provide 'egg-its :version 1.04 :type 'regular)

;;;***

;;;### (autoloads (kakusuu-input busyu-input) "egg-busyu" "egg-its/egg-busyu.el")

(autoload 'busyu-input "egg-busyu" nil t nil)

(autoload 'kakusuu-input "egg-busyu" nil t nil)

;;;***

(provide 'egg-its-autoloads)
